from typing import Optional

import sqlalchemy as sql
import chess

from db_models import ChessBoard, async_session


class UserBoard:
    def __init__(self, telegram_user_id: int):
        self.telegram_user_id = telegram_user_id

    async def create(self) -> chess.Board:
        board = chess.Board()
        async with async_session() as session:
            board_obj = ChessBoard(
                telegram_user_id=self.telegram_user_id,
                board=board.fen(),
            )
            session.add(board_obj)
            await session.commit()

        return board

    async def get(self) -> Optional[chess.Board]:
        async with async_session() as session:
            board_obj = await session.scalar(
                sql.select(ChessBoard).filter_by(telegram_user_id=self.telegram_user_id)
            )
        if board_obj is None:
            return None
        return chess.Board(board_obj.board)

    async def get_or_create(self) -> chess.Board:
        async with async_session() as session:
            board_obj = await session.scalar(
                sql.select(ChessBoard).filter_by(telegram_user_id=self.telegram_user_id)
            )
            if board_obj is not None:
                return chess.Board(board_obj.board)

            board = chess.Board()
            board_obj = ChessBoard(
                telegram_user_id=self.telegram_user_id,
                board=board.fen(),
            )
            session.add(board_obj)
            await session.commit()
            return board


    async def update(self, new_board: chess.Board) -> chess.Board:
        async with async_session() as session:
            await session.execute(
                sql.update(ChessBoard).filter_by(
                    telegram_user_id=self.telegram_user_id
                ).values(
                    board=new_board.fen()
                )
            )
            await session.commit()

        return new_board

    async def delete(self) -> None:
        async with async_session() as session:
            await session.execute(
                sql.delete(ChessBoard).filter_by(
                    telegram_user_id=self.telegram_user_id
                )
            )
            await session.commit()
